/**
    @file ft51_watchdog.h

    @brief Watchdog Timer with Adjustable Timeout Period.

    Software must feed the watchdog within a set period (as determined
    by the start_value parameter of the watchdog_enable function)
    to verify proper software execution. If a hardware or software
    failure prevents feeding the watchdog within the minimum timeout
    period, the FT51 reset is forced. Once the system has undergone
    the reset, it is possible to check with the reset_cause function
    whether the reset was caused by a watchdog overflow or normal reset.
    Watchdog timer is disabled only by power-on reset and during power-down.
    Once enabled, it cannot be disabled.
    It is enabled by the watchdog_enable function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_WATCHDOG_H__
#define __FT51_WATCHDOG_H__

#include <stdint.h>
#include "ft51.h"


/**
    @enum RESET_REASON
    @brief Explains the cause of the most recent reset.
**/
typedef enum
{
    /** Power supply was removed or interrupted. **/
    NORMAL_RESET, 
    /** Watchdog was not fed in time. **/
    WATCHDOG_RESET
}
RESET_REASON;

/**
    @brief      Watchdog Enable

    A function to start the watchdog.
    @param[in]  start_value    Watchdog start value (only bits from 0 to 4 used).
    			This value sets one bit in a 32-bit register as the start value
    			of the counter.
**/
void watchdog_enable(const uint8_t  start_value);

/**
    @brief      Watchdog Feed
    @details    The function feeds the watchdog in order to prevent it from
                reseting the system.
**/
void watchdog_feed(void);

/**
    @brief      Reset cause.

    A function to check what caused the reset:
    i.e. whether the system started after a normal reset
    or a watchdog reset.
    @return     Reason for most-recent reset.
**/
RESET_REASON reset_cause(void);

#endif // __FT51_WATCHDOG_H__